/*
 * Name:    mp_ptz.c
 *
 * Purpose: Python module interface to generic MX Pan/Tilt/Zoom functions.
 *
 * Author:  William Lavender
 *
 *-------------------------------------------------------------------------
 *
 * Copyright 2005 Illinois Institute of Technology
 *
 * See the file "LICENSE" for information on usage and redistribution
 * of this file, and for a DISCLAIMER OF ALL WARRANTIES.
 *
 */

#include "Python.h"

#include "mx_util.h"
#include "mx_record.h"
#include "mx_ptz.h"
#include "mx_handle.h"
#include "mp.h"

#include "mx_key.h"

MX_EXPORT PyObject *
MpPrivate_ptz_command_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long command;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &command );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_command( record, command );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_status_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_status( record, &status );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", status );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_pan_left_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_pan_left( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_pan_right_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_pan_right( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_pan_stop_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_pan_stop( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_pan_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle, pan_value;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_pan( record, &pan_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", pan_value );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_pan_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long pan_value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &pan_value );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_pan( record, pan_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_pan_speed_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long pan_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_pan_speed( record, &pan_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", pan_speed );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_pan_speed_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long pan_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &pan_speed );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_pan_speed( record, pan_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_tilt_up_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_tilt_up( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_tilt_down_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_tilt_down( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_tilt_stop_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_tilt_stop( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_tilt_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle, tilt_value;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_tilt( record, &tilt_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", tilt_value );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_tilt_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long tilt_value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &tilt_value );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_tilt( record, tilt_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_tilt_speed_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long tilt_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_tilt_speed( record, &tilt_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", tilt_speed );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_tilt_speed_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long tilt_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &tilt_speed );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_tilt_speed( record, tilt_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_zoom_in_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_zoom_in( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_zoom_out_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_zoom_out( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_zoom_stop_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_zoom_stop( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_zoom_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long zoom_value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_zoom( record, &zoom_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", zoom_value );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_zoom_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long zoom_value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &zoom_value );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_zoom( record, zoom_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_zoom_speed_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long zoom_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_zoom_speed( record, &zoom_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", zoom_speed );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_zoom_speed_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long zoom_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &zoom_speed );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_zoom_speed( record, zoom_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_zoom_off_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_zoom_off( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_zoom_on_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_zoom_on( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_focus_manual_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_focus_manual( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_focus_auto_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_focus_auto( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_focus_far_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_focus_far( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_focus_near_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_focus_near( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_focus_stop_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_focus_stop( record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_focus_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long focus_value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_focus( record, &focus_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", focus_value );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_focus_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long focus_value;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &focus_value );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_focus( record, focus_value );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

MX_EXPORT PyObject *
MpPrivate_ptz_get_focus_speed_cmd( PyObject *self, PyObject *args )
{
	PyObject *result;
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long focus_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "l", &handle );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_get_focus_speed( record, &focus_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	result = Py_BuildValue( "l", focus_speed );

	return result;
}

MX_EXPORT PyObject *
MpPrivate_ptz_set_focus_speed_cmd( PyObject *self, PyObject *args )
{
	MX_RECORD *record;
	long handle;
	int parse_status;
	unsigned long focus_speed;
	mx_status_type mx_status;

	parse_status = PyArg_ParseTuple( args, "ll", &handle, &focus_speed );

	if ( parse_status == 0 )
		return NULL;

	mx_status = MpPrivate_get_record_from_handle( handle, &record );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	mx_status = mx_ptz_set_focus_speed( record, focus_speed );

	if ( mx_status.code != MXE_SUCCESS )
		return MpPrivateErr_SetFromMxStatus( NULL, mx_status );

	Py_INCREF(Py_None);

	return Py_None;
}

